@@ -9,12 +9,13 @@
 # Description：自定义数据类型
 """
 from .dmE import *
+from .thread import MyThread
 
 
 class CustomE:
     def __init__(self):
         self.dm = tmp
-        self.thread = None
+        self.thread = MyThread()
         self.hwnd = None
         self.title = None
         self.account = None
